@@ -77,9 +77,9 @@ def get_formula_tex(lmargin, tmargin, rmargin, bmargin):
 	  \\immediate\\write\\foo{  "snippetwidth": "\\the\\snippetwidth",}
 	  \\immediate\\write\\foo{  "pagewidth": "\\the\\pagewidth",}
 	  \\immediate\\write\\foo{  "pageheight": "\\the\\pageheight",}
-	  \\immediate\\write\\foo{  "pagelmargin": "\\the\\pagelmargin"}
-	  \\immediate\\write\\foo{  "pagermargin": "\\the\\pagermargin"}
-	  \\immediate\\write\\foo{  "pagetmargin": "\\the\\pagetmargin"}
+	  \\immediate\\write\\foo{  "pagelmargin": "\\the\\pagelmargin",}
+	  \\immediate\\write\\foo{  "pagermargin": "\\the\\pagermargin",}
+	  \\immediate\\write\\foo{  "pagetmargin": "\\the\\pagetmargin",}
 	  \\immediate\\write\\foo{  "pagebmargin": "\\the\\pagebmargin"}
 	  \\immediate\\write\\foo{\\CloseBrace}
 	\\closeout\\foo
@@ -110,12 +110,12 @@ class Formula:
 		# print("Got height: " + str(svg_height))
 		# new_pageheight = self.dimensions["pageheight"] * math.ceil(svg_height) / svg_height
 		# new_margin = margin + (new_pageheight - self.dimensions["pageheight"]) / 2
-		top = page.dimensions["pagetmargin"] + page.dimensions["snippetheight"]
-		bottom = page.dimensions["pagebmargin"] + page.dimensions["snippetdepth"]
+		top = self.dimensions["pagetmargin"] + self.dimensions["snippetheight"]
+		bottom = self.dimensions["pagebmargin"] + self.dimensions["snippetdepth"]
 		lmargin = margin
-		tmargin = margin + 200 - top
+		tmargin = margin + 37.6402088369 - top
 		rmargin = margin
-		bmargin = margin + 200 - bottom
+		bmargin = margin + 37.6402088369 - bottom
 		self.clear()
 		self.populate(lmargin, tmargin, rmargin, bmargin, process_timeout = process_timeout)
 		
